@@ -253,10 +253,10 @@ void ResultWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
             int tmpWidth = 0;
             for (int tmpInt = 0; tmpInt < m_factors.count(); tmpInt++) {
                 if (tmpInt != 0) {
-                    tmpWidth += fm.width(QStringLiteral("*"));
+                    tmpWidth += fm.boundingRect(QStringLiteral("*")).width();
                 }
                 tmpStr.setNum(m_factors[tmpInt]);
-                fontWidth = fm.width(tmpStr);
+                fontWidth = fm.boundingRect(tmpStr).width();
                 tmpWidth += fontWidth;
             }
             if (tmpWidth <= 100)
@@ -264,14 +264,14 @@ void ResultWidget::paintEvent(QPaintEvent* /* p_paintEvent */)
 
             for (int tmpInt = 0; tmpInt < m_factors.count(); tmpInt++) {
                 if (tmpInt != 0) {
-                    fontWidth = fm.width(QStringLiteral("*"));
+                    fontWidth = fm.boundingRect(QStringLiteral("*")).width();
                     paint.drawText(old_x, old_y, fontWidth, fontHeight, Qt::AlignCenter, QStringLiteral("*"));
                     old_x += fontWidth;
                 }
 
                 tmpStr.setNum(m_factors[tmpInt]);
 
-                fontWidth = fm.width(tmpStr);
+                fontWidth = fm.boundingRect(tmpStr).width();
                 paint.drawText(old_x, old_y, fontWidth, fontHeight, Qt::AlignCenter, tmpStr);
                 old_x += fontWidth;
             }
